@@ -1,8 +1,8 @@
 from lyrebird import on_response
-from lyrebird.checker import CheckerCategory
+from lyrebird.checker import ExtensionCategory
 
 TITLE = '<示例脚本>在Response中添加Header Key'
-CATEGORY = CheckerCategory.EDITOR
+CATEGORY = ExtensionCategory.MODIFIER
 
 @on_response(rules={
     "request.url": "(?=.*poi/detail)"
