@@ -1,6 +1,6 @@
 from flask import Blueprint, request
 from flask_restful import Api
-from .common import Status, WorkMode, Manifest, DiffMode
+from .common import Status, WorkMode, Manifest, DiffMode, Render
 from .flow import Flow, FlowList
 from .mock import MockData, MockGroup, ActivatedMockGroup, MockGroupByName, MockDataLabel
 from .config import Conf
@@ -56,6 +56,7 @@ api_source.add_resource(Qrcode, '/qrcode')
 api_source.add_resource(Conf, '/conf')
 api_source.add_resource(WorkMode, '/mode', '/mode/<string:mode>')
 api_source.add_resource(DiffMode, '/diffmode')
+api_source.add_resource(Render, '/render')
 api_source.add_resource(Menu, '/menu')
 api_source.add_resource(Notice, '/notice')
 api_source.add_resource(Checker, '/checker', '/checker/<string:checker_id>')
